@@ -1,6 +1,6 @@
 package Sparrow;
 
-our $VERSION = '0.2.13';
+our $VERSION = '0.2.14';
 
 1;
 
@@ -384,6 +384,13 @@ It's useful when create tasks for swat plugins
     $ sparrow task add web nginx-check swat-nginx --host 127.0.0.1:80
 
 
+=head3 Getting task list
+
+To list all the task with projects use:
+
+B<sparrow task list>
+
+
 =head3 Run plugins
 
 There are two ways to run sparrow plugins:
@@ -613,6 +620,21 @@ Examples:
     $ sparrow task remove system disk-health
 
 
+=head3 Alternative task names notation
+
+When working with task you may use an alternative task names notation:
+
+    $project_name/$task_name
+
+Examples:
+
+    $ sparrow task run system/disk
+    $ sparrow task show system/disk
+    $ sparrow task remove system/disk
+    $ sparrow task ini system/disk
+    # so on ...
+
+
 =head2 Task boxes API
 
 Use this command to run task box
